* Output options: all can be turned on/off by adding or removing the 'NO':
  page number, date, centering, or page breaks, page length and width;
OPTIONS Spool NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=120;
* Eliminate SAS default titles and names of tables in output (TRACE ON to show);
TITLE; ODS TRACE OFF;
ODS GRAPHICS OFF;

* Location for SAS files for these models - change this path to run on your computer;
%LET filesave= F:\Example Data\Chapter 2 Data;
LIBNAME filesave "&filesave.";

TITLE "Descriptive Statistics for Example Variables in Original Data"; 
PROC FREQ  DATA=filesave.example2; TABLE sexMW demgroup; RUN;
PROC MEANS DATA=filesave.example2; VAR cognition age grip; RUN;
TITLE; 

* Import example data into work library and center predictors;
DATA work.example2; SET filesave.example2;
* Center continuous predictors;
  age85 = age - 85; LABEL age85= "age85: Age in Years (0=85)";
  grip9 = grip - 9; LABEL grip9= "grip9: Grip Strength in Pounds (0=9)";
* Creating manual contrasts between groups (demNF, demNC) to map onto model equation;
  	   IF demgroup=1 THEN DO; demNF=0; demNC=0; END; * None;
  ELSE IF demgroup=2 THEN DO; demNF=1; demNC=0; END; * Future;
  ELSE IF demgroup=3 THEN DO; demNF=0; demNC=1; END; * Current;
  ELSE                    DO; demNF=.; demNC=.; END; * Otherwise is missing; 
  LABEL demNF=	"demNF: None vs. Future Dementia"
		demNC=	"demNF: None vs. Current Dementia";
RUN;

******************************************************************************;
/* To use R2Change Macro, enter:
	N=		Total Sample Size
	DataL=	Name of dataset that stores R2 for larger model	(on ODS)
	NpredL=	Number of predictors in larger model
	DataS=	Name of dataset that stores R2 for smaller model (on ODS)
	NpredS=	Number of predictors in smaller model */

* Macro to compute R2 change F-test;
%MACRO R2Change(N, DataL, NpredL, DataS, NpredS);
DATA _NULL_; SET &DataL.; CALL SYMPUT('R2L', Rsquare);	RUN;
DATA _NULL_; SET &DataS.; CALL SYMPUT('R2S', Rsquare);	RUN;
DATA Compare; 
	RsquareL=&R2L.; RsquareS=&R2S.; RsquareDiff = RsquareL - RsquareS; 
	NpredL=&NpredL.; NpredS=&NpredS.; 
	DFnum = NpredL-NpredS; DFdenom=&N.-NpredL-1;
	Fvalue = (RsquareDiff/DFnum)/((1-RsquareL)/DFdenom);
	Pvalue = 1-PROBF(Fvalue,DFnum,DFdenom);
RUN;
TITLE "R2 Change F-Test for &DataL. (L) vs. &DataS. (S)"; 
PROC PRINT DATA=Compare NOOBS; VAR RsquareL--Pvalue; RUN; TITLE;
%MEND R2Change;

/* To Use Asymp Macro, enter:
	DV=			Name of dependent variable
	AnoData=	Name of dataset that stores MSE for model (on ODS)
	InvData=	Name of dataset that stores X'X inv matrix for model (on ODS)
	Npred=		Number of predictors in model (include row of dots) */

* Macro to compute asymptotic covariance matrix;
%MACRO Asymp(DV, AnoData, InvData, Npred);
DATA _NULL_; SET &AnoData.; WHERE INDEX(Source,"Error")>0;
	CALL SYMPUT('MSE', MS); RUN;
DATA &InvData.; SET &InvData.; MSE=&MSE.;
	ARRAY list (%EVAL(2+&Npred.)) Intercept--&DV.;
	DO i=1 TO %EVAL(2+&Npred.); list(i)=MSE*list(i);
	END; DROP MSE i;
RUN;
/*TITLE "Asymptotic Covariance Matrix of Fixed Effects for &InvData."; 
PROC PRINT DATA=&InvData. NOOBS; RUN; TITLE;*/
%MEND Asymp;

/* To use Regions Macro, enter:
	FixData=	Name of dataset that stores fixed effects for model	(on ODS)
	InvData=	Name of dataset that stores X'X inv matrix for model  (on ODS)
	Pred=		Case-sensitive name of predictor effect regions are for 
	Mod=		Case-sensitive name of moderator effect (for region values)
	ModCenter=	Centering point of moderator predictor
	Interact=	Case-sensitive name of interaction effect */

%MACRO Regions(FixData, InvData, Pred, Mod, ModCenter, Interact);
DATA _NULL_; SET &FixData.; WHERE Parameter="&Pred.";
	CALL SYMPUT('Bpred', Estimate); CALL SYMPUT('SEpred', StdErr); RUN;	
DATA _NULL_; SET &FixData.; WHERE Parameter="&Interact.";
	CALL SYMPUT('Binter', Estimate); CALL SYMPUT('SEinter', StdErr); RUN; 
DATA _NULL_; SET &InvData.; WHERE INDEX(Parameter,"&Interact.")>0;
	CALL SYMPUT('CovPredInt', &Pred.); RUN;	
%PUT Bpred=&Bpred. SEpred=&SEpred. Binter=&Binter. SEinter=&SEinter. CovPredInt=&CovPredInt.;
DATA Regions;  * Intermediate calculations;
	A=(1.96*1.96)*(&SEinter.*&SEinter.)-(&Binter.*&Binter.);
	B=2*((1.96*1.96)*&CovPredInt.-(&Bpred.*&Binter.));
	C=(1.96*1.96*&SEpred.*&SEpred.)-(&Bpred.*&Bpred.);
	CenteredLower=((-1*B)+SQRT((B*B)-4*A*C))/(2*A); CALL SYMPUT('cenlower',ROUND(CenteredLower,.001));
	CenteredUpper=((-1*B)-SQRT((B*B)-4*A*C))/(2*A); CALL SYMPUT('cenupper',ROUND(CenteredUpper,.001));
	UncenteredLower=CenteredLower+&ModCenter.; CALL SYMPUT('uncenlower',ROUND(UncenteredLower,.001));
	UncenteredUpper=CenteredUpper+&ModCenter.; CALL SYMPUT('uncenupper',ROUND(UncenteredUpper,.001));
RUN;
TITLE1 "The effect of &pred. will be significant at centered values of &mod. BELOW the lower bound"; 
TITLE2 "and ABOVE the upper bound, which translate to these uncentered lower and upper bounds.";  
PROC PRINT DATA=Regions NOOBS; VAR CenteredLower--UncenteredUpper; RUN; TITLE1;	TITLE2;
%MEND Regions;
******************************************************************************;

******************************************************************************;
***** MODELS WITH SEX AND DEMENTIA GROUP VIA MANUAL GROUP CONTRASTS;
******************************************************************************;

TITLE1 "Eq 2.7: Model with Age, Grip, Sex (0=Men, 1=Women)";
PROC GLM DATA=work.example2; 
* Model Y = fixed effects, options after / print extra output;
  MODEL cognition = age85 grip9 sexMW / SOLUTION SS3; *EFFECTSIZE;
* Save pieces of output for use in macros (optional);
  ODS OUTPUT FitStatistics=work.Rsq2_7;
* Intercepts per sex (age=85, grip=9);
  ESTIMATE "Intercept for Men"   intercept 1 sexMW 0;
  ESTIMATE "Intercept for Women" intercept 1 sexMW 1;
* Need both RUN and QUIT, shut off title;
RUN; QUIT; TITLE1;

TITLE1 "Eq 2.8: Model adding Dementia Group (demNF, demNC) as manual contrasts";
PROC GLM DATA=work.example2; 
* Model Y = fixed effects, options after / print extra output;
  MODEL cognition = age85 grip9 sexMW demNF demNC / SOLUTION SS3; * EFFECTSIZE;
* Request group means (hold age=85, grip=9, men);
  ESTIMATE "Intercept for None"    intercept 1 demNF 0 demNC 0;
  ESTIMATE "Intercept for Future"  intercept 1 demNF 1 demNC 0;
  ESTIMATE "Intercept for Current" intercept 1 demNF 0 demNC 1;
* Request group differences;
  ESTIMATE "None   vs. Future"     demNF  1 demNC 0;
  ESTIMATE "None   vs. Current"    demNF  0 demNC 1;
  ESTIMATE "Future vs. Current"    demNF -1 demNC 1;
* Save pieces of output for use in macros (optional);
  ODS OUTPUT FitStatistics=work.Rsq2_8;
* Need both RUN and QUIT, shut off titles;
RUN; QUIT; TITLE1;
* Call macro to test R2 change from Eq 2_8 vs. Eq 2_7;
%R2Change(N=550, DataL=work.Rsq2_8, NpredL=5, DataS=work.Rsq2_7, NpredS=3);
 
TITLE1 "Eq 2.9: Model with Age by Grip Interaction";
PROC GLM DATA=work.example2; 
* Model Y = fixed effects, options after / print extra output;
  MODEL cognition = age85 grip9 sexMW demNF demNC age85*grip9 / SOLUTION SS3 INVERSE; *EFFECTSIZE;
* Request simple effects at other values of age and grip;
  ESTIMATE "Age Effect for Grip=6" 	age85 1 age85*grip9 -3;
  ESTIMATE "Age Effect for Grip=9" 	age85 1 age85*grip9  0;
  ESTIMATE "Age Effect for Grip=12" age85 1 age85*grip9  3;
  ESTIMATE "Age Effect for Grip=9.66813" 	age85 1 age85*grip9 0.66813;
  ESTIMATE "Age Effect for Grip=18.4817" 	age85 1 age85*grip9 9.66813;
  ESTIMATE "Grip Effect for Age=80" grip9 1 age85*grip9 -5;
  ESTIMATE "Grip Effect for Age=85" grip9 1 age85*grip9  0;
  ESTIMATE "Grip Effect for Age=90" grip9 1 age85*grip9  5;
  ESTIMATE "Grip Effect for Age=70.1856" grip9 1 age85*grip9 -14.8144;
  ESTIMATE "Grip Effect for Age=82.7143" grip9 1 age85*grip9 -2.28566;
* Save pieces of output for use in macros (optional);
  ODS OUTPUT FitStatistics=work.Rsq2_9 InvXPX=work.Inv2_9 
			 OverallANOVA=work.Ano2_9  ParameterEstimates=work.Fix2_9;
* Need both RUN and QUIT, shut off title;
RUN; QUIT; TITLE1;
* Call macro to make asymptotic covariance matrix;
%Asymp(DV=cognition, AnoData=work.Ano2_9, InvData=work.Inv2_9, Npred=6);
* Call macro to calculate regions of significance for age effect;
%Regions(FixData=work.Fix2_9, InvData=work.Inv2_9, Pred=age85, Mod=grip9, ModCenter=9, Interact=age85*grip9);
* Call macro to calculate regions of significance for grip effect;
%Regions(FixData=work.Fix2_9, InvData=work.Inv2_9, Pred=grip9, Mod=age85, ModCenter=85, Interact=age85*grip9);

TITLE1 "Eq 2.13: Add Sex by Dementia Interaction";
PROC GLM DATA=work.example2; 
* Model Y = fixed effects, options after / print extra output;
  MODEL cognition = age85 grip9 sexMW demNF demNC age85*grip9 sexMW*demNF sexMW*demNC / SOLUTION SS3 INVERSE; * EFFECTSIZE;
* Save pieces of output for use in macros (optional);
  ODS OUTPUT FitStatistics=work.Rsq2_13 InvXPX=work.Inv2_13 
			 OverallANOVA=work.Ano2_13  ParameterEstimates=work.Fix2_13;
* Request group means (hold age=85, grip=9);
  ESTIMATE "Intercept: None    Men"    intercept 1 demNF 0 demNC 0 sexMW 0 sexMW*demNF 0 sexMW*demNC 0;
  ESTIMATE "Intercept: Future  Men"    intercept 1 demNF 1 demNC 0 sexMW 0 sexMW*demNF 0 sexMW*demNC 0;
  ESTIMATE "Intercept: Current Men"    intercept 1 demNF 0 demNC 1 sexMW 0 sexMW*demNF 0 sexMW*demNC 0;
  ESTIMATE "Intercept: None    Women"  intercept 1 demNF 0 demNC 0 sexMW 1 sexMW*demNF 0 sexMW*demNC 0;
  ESTIMATE "Intercept: Future  Women"  intercept 1 demNF 1 demNC 0 sexMW 1 sexMW*demNF 1 sexMW*demNC 0;
  ESTIMATE "Intercept: Current Women"  intercept 1 demNF 0 demNC 1 sexMW 1 sexMW*demNF 0 sexMW*demNC 1;
* Request simple effects of dementia per sex;
  ESTIMATE "None   vs. Future:  Men"     demNF  1 demNC 0 sexMW*demNF  0 sexMW*demNC 0;
  ESTIMATE "None   vs. Current: Men"     demNF  0 demNC 1 sexMW*demNF  0 sexMW*demNC 0;
  ESTIMATE "Future vs. Current: Men"     demNF -1 demNC 1 sexMW*demNF  0 sexMW*demNC 0;
  ESTIMATE "None   vs. Future:  Women"   demNF  1 demNC 0 sexMW*demNF  1 sexMW*demNC 0;
  ESTIMATE "None   vs. Current: Women"   demNF  0 demNC 1 sexMW*demNF  0 sexMW*demNC 1;
  ESTIMATE "Future vs. Current: Women"   demNF -1 demNC 1 sexMW*demNF -1 sexMW*demNC 1;
* Request simple effects of sex per dementia group;
  ESTIMATE "Men vs. Women: None"		 sexMW 1 sexMW*demNF 0 sexMW*demNC 0;
  ESTIMATE "Men vs. Women: Future" 	     sexMW 1 sexMW*demNF 1 sexMW*demNC 0;
  ESTIMATE "Men vs. Women: Current"	     sexMW 1 sexMW*demNF 0 sexMW*demNC 1;
* Need both RUN and QUIT, shut off title;
RUN; QUIT; TITLE1;
* Call macro to test R2 change from Eq 2_13 vs. Eq 2_9;
%R2Change(N=550, DataL=work.Rsq2_13, NpredL=8, DataS=work.Rsq2_9, NpredS=6);
* Call macro to make asymptotic covariance matrix;
%Asymp(DV=cognition, AnoData=work.Ano2_13, InvData=work.Inv2_13, Npred=8);
* Call macro to calculate regions of significance for age effect;
%Regions(FixData=work.Fix2_13, InvData=work.Inv2_13, Pred=age85, Mod=grip9, ModCenter=9, Interact=age85*grip9);
* Call macro to calculate regions of significance for grip effect;
%Regions(FixData=work.Fix2_13, InvData=work.Inv2_13, Pred=grip9, Mod=age85, ModCenter=85, Interact=age85*grip9);

TITLE1 "Eq. 2.18: Model Three-Way Interaction of Sex by Age by Grip";
PROC GLM DATA=work.example2; 
* Model Y = fixed effects, options after / print extra output;
    MODEL cognition = age85 grip9 sexMW demNF demNC age85*grip9 sexMW*demNF sexMW*demNC 
	                  sexMW*age85 sexMW*grip9 sexMW*age85*grip9 / SOLUTION SS3; *EFFECTSIZE;
* Save pieces of output for use in macros (optional);
  ODS OUTPUT FitStatistics=work.Rsq2_18;
* Request simple effects of Age;
  ESTIMATE "Age for Grip=6,  Men"		 age85 1 age85*grip9 -3 sexMW*age85 0 sexMW*age85*grip9  0;
  ESTIMATE "Age for Grip=9,  Men"		 age85 1 age85*grip9  0 sexMW*age85 0 sexMW*age85*grip9  0;
  ESTIMATE "Age for Grip=12, Men"		 age85 1 age85*grip9  3 sexMW*age85 0 sexMW*age85*grip9  0;
  ESTIMATE "Age for Grip=6,  Women"		 age85 1 age85*grip9 -3 sexMW*age85 1 sexMW*age85*grip9 -3;
  ESTIMATE "Age for Grip=9,  Women"		 age85 1 age85*grip9  0 sexMW*age85 1 sexMW*age85*grip9  0;
  ESTIMATE "Age for Grip=12, Women"		 age85 1 age85*grip9  3 sexMW*age85 1 sexMW*age85*grip9  3;
* Request simple effects of Grip;
  ESTIMATE "Grip for Age=80, Men"		 grip9 1 age85*grip9 -5 grip9*sexMW 0 sexMW*age85*grip9  0;
  ESTIMATE "Grip for Age=85, Men"		 grip9 1 age85*grip9  0 grip9*sexMW 0 sexMW*age85*grip9  0;
  ESTIMATE "Grip for Age=90, Men"		 grip9 1 age85*grip9  5 grip9*sexMW 0 sexMW*age85*grip9  0;
  ESTIMATE "Grip for Age=80, Women"		 grip9 1 age85*grip9 -5 grip9*sexMW 1 sexMW*age85*grip9 -5;
  ESTIMATE "Grip for Age=85, Women"		 grip9 1 age85*grip9  0 grip9*sexMW 1 sexMW*age85*grip9  0;
  ESTIMATE "Grip for Age=90, Women"		 grip9 1 age85*grip9  5 grip9*sexMW 1 sexMW*age85*grip9  5;
* Request simple effects of Sex per Dementia, hold Age=85, Grip=9;
  ESTIMATE "Sex for None"		         sexMW 1 sexMW*demNF 0 sexMW*demNC 0 sexMW*age85 0 sexMW*grip9 0 sexMW*age85*grip9 0;
  ESTIMATE "Sex for Future"		         sexMW 1 sexMW*demNF 1 sexMW*demNC 0 sexMW*age85 0 sexMW*grip9 0 sexMW*age85*grip9 0;
  ESTIMATE "Sex for Current"	         sexMW 1 sexMW*demNF 0 sexMW*demNC 1 sexMW*age85 0 sexMW*grip9 0 sexMW*age85*grip9 0;
* Request simple effects of Dementia per Sex, not conditional on age or grip;
  ESTIMATE "None   vs. Future:  Men"     demNF  1 demNC 0 sexMW*demNF  0 sexMW*demNC  0;
  ESTIMATE "None   vs. Current: Men"     demNF  0 demNC 1 sexMW*demNF  0 sexMW*demNC  0;
  ESTIMATE "Future vs. Current: Men"     demNF -1 demNC 1 sexMW*demNF  0 sexMW*demNC  0;
  ESTIMATE "None   vs. Future:  Women"   demNF  1 demNC 0 sexMW*demNF  1 sexMW*demNC  0;
  ESTIMATE "None   vs. Current: Women"   demNF  0 demNC 1 sexMW*demNF  0 sexMW*demNC  1;
  ESTIMATE "Future vs. Current: Women"   demNF -1 demNC 1 sexMW*demNF -1 sexMW*demNC  1;
* Request simple two-way interactions within Sex*Dementia Group;
  ESTIMATE "Sex by None vs. Future"      sexMW*demNF  1 sexMW*demNC 0;
  ESTIMATE "Sex by None vs. Current"     sexMW*demNF  0 sexMW*demNC 1;
  ESTIMATE "Sex by Future vs. Current"   sexMW*demNF -1 sexMW*demNC 1;
* Request simple two-way interactions of age*grip;
  ESTIMATE "Age by Grip: Men"			 age85*grip9 1 age85*grip9*sexMW  0;
  ESTIMATE "Age by Grip: Women"		     age85*grip9 1 age85*grip9*sexMW  1;
* Request simple two-way interactions of sex*age;
  ESTIMATE "Sex by Age:  Grip=6"		 sexMW*age85 1 age85*grip9*sexMW -3;
  ESTIMATE "Sex by Age:  Grip=9"		 sexMW*age85 1 age85*grip9*sexMW  0;
  ESTIMATE "Sex by Age:  Grip=12"		 sexMW*age85 1 age85*grip9*sexMW  3;
* Request simple two-way interactions of sex*grip;
  ESTIMATE "Sex by Grip: Age=80"		 sexMW*grip9 1 age85*grip9*sexMW -5;
  ESTIMATE "Sex by Grip: Age=85"		 sexMW*grip9 1 age85*grip9*sexMW  0;
  ESTIMATE "Sex by Grip: Age=90"		 sexMW*grip9 1 age85*grip9*sexMW  5;
* Need both RUN and QUIT, shut off title;
RUN; QUIT; TITLE1;
* Call macro to test R2 change from Eq 2_18 vs. Eq 2_13;
%R2Change(N=550, DataL=work.Rsq2_18, NpredL=11, DataS=work.Rsq2_13, NpredS=8);


******************************************************************************;
***** MODELS WITH SEX AND DEMENTIA GROUP ON CLASS STATEMENT;
******************************************************************************;

* Create formats for output using categorical predictors;
* Then uses numeric/alphabetical order to order categories!;
PROC FORMAT;
	VALUE Gender 0="2Men" 1="1Women"; 					* So Men stay ref;
	VALUE Dementia 1="4None" 2="2Future" 3="3Current";  * So None stays ref;
RUN;

TITLE1 "Eq 2.7: Model with Age, Grip, Sex (0=Men, 1=Women)";
PROC GLM DATA=work.example2; 
* CLASS statement lists categorical predictors it will create contrasts for;
* FORMAT asks it to print value labels defined above;
  CLASS sexMW; FORMAT sexMW Gender.;
* Model Y = fixed effects, options after / print extra output;
  MODEL cognition = age85 grip9 sexMW / SOLUTION SS3; * EFFECTSIZE;
* Intercepts per sex age-85, grip=9);
  ESTIMATE "Intercept for 2Men"   intercept 1 sexMW 0 1;
  ESTIMATE "Intercept for 1Women" intercept 1 sexMW 1 0;
* Need both RUN and QUIT, shut off title;
RUN; QUIT; TITLE1;

TITLE1 "Eq 2.8: Model adding Dementia Group (2=Future, 3=Current, 4=None)";
TITLE2 "Uses CLASS statement to ask SAS to make our group contrasts";
PROC GLM DATA=work.example2; 
* CLASS statement lists categorical predictors it will create contrasts for;
* FORMAT asks it to print value labels defined above;
  CLASS sexMW demgroup; FORMAT sexMW Gender. demgroup Dementia.;
* Model Y = fixed effects, options after / print extra output;
  MODEL cognition = age85 grip9 sexMW demgroup / SOLUTION SS3; * EFFECTSIZE;
* Request group means (age=85, grip=9, have to say is for men) - group= F C N;
  ESTIMATE "Intercept for 4None"    intercept 1 sexMW 0 1 demgroup  0 0 1;
  ESTIMATE "Intercept for 2Future"  intercept 1 sexMW 0 1 demgroup  1 0 0;
  ESTIMATE "Intercept for 3Curent"  intercept 1 sexMW 0 1 demgroup  0 1 0;
* Request group differences, group= F C N;
  ESTIMATE "4None   vs. 2Future"    demgroup   1  0 -1;
  ESTIMATE "4None   vs. 3Current"   demgroup   0  1 -1;
  ESTIMATE "2Future vs. 3Current"   demgroup  -1  1  0; 
* Need both RUN and QUIT, shut off titles;
RUN; QUIT; TITLE1; TITLE2;

TITLE1 "Eq 2.8: Model adding Dementia Group (2=Future, 3=Current, 4=None)";
TITLE2 "Uses CLASS statement to ask SAS to make our group contrasts";
TITLE3 "Replaces ESTIMATEs with LSMEANS to group means and differences";
PROC GLM DATA=work.example2; 
* CLASS statement lists categorical predictors it will create contrasts for;
* FORMAT asks it to print value labels defined above;
  CLASS sexMW demgroup; FORMAT sexMW Gender. demgroup Dementia.;
* Model Y = fixed effects, options after / print extra output;
  MODEL cognition = age85 grip9 sexMW demgroup / SOLUTION SS3; * EFFECTSIZE;
* Request group means and differences (AT age=85, grip=9, MARGINALIZED across gender, though);
  LSMEANS demgroup / TDIFF STDERR PDIFF=ALL AT (age85 grip9) = (0 0);
* Need both RUN and QUIT, shut off titles;
RUN; QUIT; TITLE1; TITLE2; TITLE3;

TITLE1 "Eq 2.9: Model with Age by Grip Interaction";
PROC GLM DATA=work.example2; 
* CLASS statement lists categorical predictors it will create contrasts for;
* FORMAT asks it to print value labels defined above;
  CLASS sexMW demgroup; FORMAT sexMW Gender. demgroup Dementia.;
* Model Y = fixed effects, options after / print extra output;
  MODEL cognition = age85 grip9 sexMW demgroup age85*grip9 / SOLUTION SS3 INVERSE; *EFFECTSIZE;
* Request simple effects at other values of age and grip;
  ESTIMATE "Age Effect for Grip=6" 	age85 1 age85*grip9 -3;
  ESTIMATE "Age Effect for Grip=9" 	age85 1 age85*grip9  0;
  ESTIMATE "Age Effect for Grip=12" age85 1 age85*grip9  3;
  ESTIMATE "Grip Effect for Age=80" grip9 1 age85*grip9 -5;
  ESTIMATE "Grip Effect for Age=85" grip9 1 age85*grip9  0;
  ESTIMATE "Grip Effect for Age=90" grip9 1 age85*grip9  5;
* Save pieces of output for use in macros (optional);
  ODS OUTPUT InvXPX=work.Inv2_9 OverallANOVA=work.Ano2_9;
* Need both RUN and QUIT, shut off title;
RUN; QUIT; TITLE1;
* Call macro to print asymptotic covariance matrix;
%Asymp(DV=cognition, AnoData=work.Ano2_9, InvData=work.Inv2_9, Npred=9);

TITLE1 "Eq 2.13: Add Sex by Dementia Interaction";
PROC GLM DATA=work.example2; 
* CLASS statement lists categorical predictors it will create contrasts for;
* FORMAT asks it to print value labels defined above;
  CLASS sexMW demgroup; FORMAT sexMW Gender. demgroup Dementia.;
* Model Y = fixed effects, options after / print extra output;
  MODEL cognition = age85 grip9 sexMW demgroup age85*grip9 sexMW*demgroup / SOLUTION SS3; *EFFECTSIZE;
* Save pieces of output for use in macros (optional);
  ODS OUTPUT FitStatistics=work.Rsq2_13;
* Request group means (hold age=85, grip=9) -- sex*demgroup= WF WC WN MF MC MN based on CLASS order;
	ESTIMATE "Intercept for 4None   2Men"    intercept 1 demgroup 0 0 1 sexMW 0 1 sexMW*demgroup 0 0 0 0 0 1;
	ESTIMATE "Intercept for 2Future 2Men"    intercept 1 demgroup 1 0 0 sexMW 0 1 sexMW*demgroup 0 0 0 1 0 0;
	ESTIMATE "Intercept for 3Curent 2Men"    intercept 1 demgroup 0 1 0 sexMW 0 1 sexMW*demgroup 0 0 0 0 1 0;
	ESTIMATE "Intercept for 4None   1Women"  intercept 1 demgroup 0 0 1 sexMW 1 0 sexMW*demgroup 0 0 1 0 0 0;
	ESTIMATE "Intercept for 2Future 1Women"  intercept 1 demgroup 1 0 0 sexMW 1 0 sexMW*demgroup 1 0 0 0 0 0;
	ESTIMATE "Intercept for 3Curent 1Women"  intercept 1 demgroup 0 1 0 sexMW 1 0 sexMW*demgroup 0 1 0 0 0 0;
* Request simple effects of dementia per sex -- sex*demgroup= WF WC WN MF MC MN, add /E to check;
	ESTIMATE "4None   vs. 2Future:  2Men"    demgroup   1  0 -1  sexMW*demgroup  0  0  0  1  0 -1;
	ESTIMATE "4None   vs. 3Current: 2Men"    demgroup   0  1 -1  sexMW*demgroup  0  0  0  0  1 -1;
	ESTIMATE "2Future vs. 3Current: 2Men"    demgroup  -1  1  0  sexMW*demgroup  0  0  0 -1  1  0;
	ESTIMATE "4None   vs. 2Future:  1Women"  demgroup   1  0 -1  sexMW*demgroup  1  0 -1  0  0  0;
	ESTIMATE "4None   vs. 3Current: 1Women"  demgroup   0  1 -1  sexMW*demgroup  0  1 -1  0  0  0;
	ESTIMATE "2Future vs. 3Current: 1Women"  demgroup  -1  1  0  sexMW*demgroup -1  1  0  0  0  0;
* Request simple effects of sex per dementia group -- sex*demgroup= WF WC WN MF MC MN, add /E to check;
	ESTIMATE "2Men vs. 1Women: 4None"		 sexMW 1 -1     sexMW*demgroup  0  0  1  0  0 -1;
	ESTIMATE "2Men vs. 1Women: 2Future"	     sexMW 1 -1     sexMW*demgroup  1  0  0 -1  0  0;
	ESTIMATE "2Men vs. 1Women: 3Curent"	     sexMW 1 -1     sexMW*demgroup  0  1  0  0 -1  0;
* Need both RUN and QUIT, shut off title;
RUN; QUIT; TITLE1;

TITLE1 "Eq 2.13: Add Sex by Dementia Interaction";
TITLE2 "Replaces ESTIMATEs with LSMEANS to group means and differences";
PROC GLM DATA=work.example2; 
* CLASS statement lists categorical predictors it will create contrasts for;
* FORMAT asks it to print value labels defined above;
  CLASS sexMW demgroup; FORMAT sexMW Gender. demgroup Dementia.;
* Model Y = fixed effects, options after / print extra output;
  MODEL cognition = age85 grip9 sexMW demgroup age85*grip9 sexMW*demgroup / SOLUTION SS3; *EFFECTSIZE;
* Save pieces of output for use in macros (optional);
  ODS OUTPUT FitStatistics=work.Rsq2_13;
* Request group means and differences (hold age=85, grip=9);
  LSMEANS sexMW*demgroup / PDIFF=ALL SLICE=sexMW SLICE=demgroup;
* Need both RUN and QUIT, shut off title;
RUN; QUIT; TITLE1;

TITLE1 "Eq. 2.18: Model Three-Way Interaction of Sex by Age by Grip";
PROC GLM DATA=work.example2; 
* CLASS statement lists categorical predictors it will create contrasts for;
* FORMAT asks it to print value labels defined above;
  CLASS sexMW demgroup; FORMAT sexMW Gender. demgroup Dementia.;
* Model Y = fixed effects, options after / print extra output;
    MODEL cognition = age85 grip9 sexMW demgroup age85*grip9 sexMW*demgroup 
	                  sexMW*age85 sexMW*grip9 sexMW*age85*grip9 / SOLUTION SS3 EFFECTSIZE;
* Save pieces of output for use in macros (optional);
  ODS OUTPUT FitStatistics=work.Rsq2_18;
* Request simple effects of Age;
  ESTIMATE "Age for Grip=6,  2Men"		 age85 1 age85*grip9 -3 sexMW*age85 0 1 sexMW*age85*grip9  0 -3;
  ESTIMATE "Age for Grip=9,  2Men"		 age85 1 age85*grip9  0 sexMW*age85 0 1 sexMW*age85*grip9  0  0;
  ESTIMATE "Age for Grip=12, 2Men"		 age85 1 age85*grip9  3 sexMW*age85 0 1 sexMW*age85*grip9  0  3;
  ESTIMATE "Age for Grip=6,  1Women"	 age85 1 age85*grip9 -3 sexMW*age85 1 0 sexMW*age85*grip9 -3  0;
  ESTIMATE "Age for Grip=9,  1Women"	 age85 1 age85*grip9  0 sexMW*age85 1 0 sexMW*age85*grip9  0  0;
  ESTIMATE "Age for Grip=12, 1Women"	 age85 1 age85*grip9  3 sexMW*age85 1 0 sexMW*age85*grip9  3  0;
* Request simple effects of Grip;
  ESTIMATE "Grip for Age=80, 2Men"		 grip9 1 age85*grip9 -5 grip9*sexMW 0 1 sexMW*age85*grip9  0 -5;
  ESTIMATE "Grip for Age=85, 2Men"		 grip9 1 age85*grip9  0 grip9*sexMW 0 1 sexMW*age85*grip9  0  0;
  ESTIMATE "Grip for Age=90, 2Men"		 grip9 1 age85*grip9  5 grip9*sexMW 0 1 sexMW*age85*grip9  0  5;
  ESTIMATE "Grip for Age=80, 1Women"	 grip9 1 age85*grip9 -5 grip9*sexMW 1 0 sexMW*age85*grip9 -5  0;
  ESTIMATE "Grip for Age=85, 1Women"	 grip9 1 age85*grip9  0 grip9*sexMW 1 0 sexMW*age85*grip9  0  0;
  ESTIMATE "Grip for Age=90, 1Women"	 grip9 1 age85*grip9  5 grip9*sexMW 1 0 sexMW*age85*grip9  5  0;
* Request simple effects of Sex per Dementia, hold Age=85, Grip=9;
  ESTIMATE "Sex for 4None"		         sexMW 1 -1 sexMW*demgroup  0  0  1  0  0 -1 sexMW*age85 0 0 sexMW*grip9 0 0 sexMW*age85*grip9 0 0 /E;
  ESTIMATE "Sex for 2Future"		     sexMW 1 -1 sexMW*demgroup  1  0  0 -1  0  0 sexMW*age85 0 0 sexMW*grip9 0 0 sexMW*age85*grip9 0 0 /E;
  ESTIMATE "Sex for 3Current"	         sexMW 1 -1 sexMW*demgroup  0  1  0  0 -1  0 sexMW*age85 0 0 sexMW*grip9 0 0 sexMW*age85*grip9 0 0 /E;
* Request simple effects of Dementia per Sex, not conditional on age or grip;
  ESTIMATE "4None   vs. 2Future:  2Men"   demgroup  1  0 -1 sexMW*demgroup  0  0  0  1  0 -1;
  ESTIMATE "4None   vs. 3Current: 2Men"   demgroup  0  1 -1 sexMW*demgroup  0  0  0  0  1 -1;
  ESTIMATE "4Future vs. 3Current: 2Men"   demgroup -1  1  0 sexMW*demgroup  0  0  0 -1  1  0;
  ESTIMATE "2None   vs. 2Future:  1Women" demgroup  1  0 -1 sexMW*demgroup  1  0 -1  0  0  0;
  ESTIMATE "2None   vs. 3Current: 1Women" demgroup  0  1 -1 sexMW*demgroup  0  1 -1  0  0  0;
  ESTIMATE "2Future vs. 3Current: 1Women" demgroup -1  1  0 sexMW*demgroup -1  1  0  0  0  0;
* Request simple two-way interactions within Sex*Dementia Group, sex*demgroup= WF WC WN MF MC MN based on CLASS order;
  ESTIMATE "Sex by 4None   vs. 2Future"  sexMW*demgroup -1  0  1  1  0 -1 /E;
  ESTIMATE "Sex by 4None   vs. 3Current" sexMW*demgroup  0 -1  1  0  1 -1 /E;
  ESTIMATE "Sex by 2Future vs. 3Current" sexMW*demgroup  1 -1  0 -1  1  0 /E;
* Request simple two-way interactions of age*grip;
  ESTIMATE "Age by Grip: 2Men"			 age85*grip9 1 age85*grip9*sexMW  0 1;
  ESTIMATE "Age by Grip: 1Women"		 age85*grip9 1 age85*grip9*sexMW  1 0;
* Request simple two-way interactions of sex*age;
  ESTIMATE "Sex by Age:  Grip=6"		 sexMW*age85 1 -1 age85*grip9*sexMW -3  3;
  ESTIMATE "Sex by Age:  Grip=9"		 sexMW*age85 1 -1 age85*grip9*sexMW  0  0;
  ESTIMATE "Sex by Age:  Grip=12"		 sexMW*age85 1 -1 age85*grip9*sexMW  3 -3;
* Request simple two-way interactions of sex*grip;
  ESTIMATE "Sex by Grip: Age=80"		 sexMW*grip9 1 -1 age85*grip9*sexMW -5  5;
  ESTIMATE "Sex by Grip: Age=85"		 sexMW*grip9 1 -1 age85*grip9*sexMW  0  0;
  ESTIMATE "Sex by Grip: Age=90"		 sexMW*grip9 1 -1 age85*grip9*sexMW  5 -5;
* Need both RUN and QUIT, shut off title;
RUN; QUIT; TITLE1;
* Call macro to test R2 change from Eq 2_18 vs. Eq 2_13;
%R2Change(N=550, DataL=work.Rsq2_18, NpredL=11, DataS=work.Rsq2_13, NpredS=8);
